######## FOR-RESTOR Synthesis Phil Trans Paper Analysis ##########
######## Authors: Lindsay F Banin, Elizabeth Raine ###############
######## MORTALITY - COVARIATE MODELS with Binomial (cloglog)#####
######## 28 June 2022 ############################################
######## Analyses run in R Version 4.0.4 #########################

install.packages("glmmTMB")
install.packages("dplyr")
install.packages("MuMIn")
install.packages("performance")
install.packages("DHARMa")
install.packages("ggplot2")
install.packages("ggeffects")
install.packages("LaplacesDemon")
install.packages("broom")
install.packages("broom.mixed")
install.packages("dotwhisker")
library(lme4)
library(nlme)
library(stats)
library(glmmTMB)
library(dplyr)
library(MuMIn)
library(performance)
library(DHARMa)
library(ggplot2)
library(ggeffects)
library(LaplacesDemon)
library(emmeans)

# Load data
s_dat <- read.csv("df_survival_Nov2022.csv")
str(s_dat)
s_dat$yr_cat <- as.character(s_dat$yr_cat)

# Subset for Duration - when duration yr_cat = 1, 2, 3, 4, 5, 7.5, 10
s_dat_1 <- subset(s_dat, yr_cat=="1")
s_dat_2 <- subset(s_dat, yr_cat=="2")
s_dat_3 <- subset(s_dat, yr_cat=="3")
s_dat_4 <- subset(s_dat, yr_cat=="4")
s_dat_7.5 <- subset(s_dat, yr_cat=="7.5")
s_dat_10 <- subset(s_dat, yr_cat=="10")

# Limit to variables for analysis
s_modvars <- c("network_origin","study","UIC","plot_id","species_full","genus","species", "family","duration_months", "vals_elev","vals_temp","vals_maxTwm",
"vals_minTcm","vals_precip","vals_pwq","vals_pdq","w_meanWD","forest_condition",
"planting_sp_no","survival_per","sample_weight","treatment","number_alive","number_dead")

s_dat_1 <- s_dat_1[s_modvars]
s_dat_2 <- s_dat_2[s_modvars]
s_dat_3 <- s_dat_3[s_modvars]
s_dat_4 <- s_dat_4[s_modvars]
s_dat_7.5 <- s_dat_7.5[s_modvars]
s_dat_10 <- s_dat_10[s_modvars]

# Create mortality response variable for binomial models
mortresp1 <- cbind(s_dat_1$number_dead, s_dat_1$number_alive)
mortresp2 <- cbind(s_dat_2$number_dead, s_dat_2$number_alive)
mortresp3 <- cbind(s_dat_3$number_dead, s_dat_3$number_alive)
mortresp4 <- cbind(s_dat_4$number_dead, s_dat_4$number_alive)
mortresp7.5 <- cbind(s_dat_7.5$number_dead, s_dat_7.5$number_alive)
mortresp10 <- cbind(s_dat_10$number_dead, s_dat_10$number_alive)

######### GLMMTMB INTERCEPT ONLY MODELS
# Year 1 
M1_mort_1yr <- glmmTMB(mortresp1~1 
+(1|UIC/species_full) + (1|plot_id),
data=s_dat_1,
family = binomial(link = "cloglog"),
na.action=na.fail)
summary(M1_mort_1yr)
pred_1yr <- emmeans(M1_mort_1yr,~1, type='response')
pred_1yr
# Year 2 
M1_mort_2yr <- glmmTMB(mortresp2~1 
+(1|UIC/species_full) + (1|plot_id),
data=s_dat_2,
family = binomial(link = "cloglog"),
na.action=na.fail)
summary(M1_mort_2yr)
pred_2yr <- emmeans(M1_mort_2yr,~1, type='response')
pred_2yr
# Year 3 
M1_mort_3yr <- glmmTMB(mortresp3~1 
+(1|UIC/species_full) + (1|plot_id),
data=s_dat_3,
family = binomial(link = "cloglog"),
na.action=na.fail)
summary(M1_mort_3yr)
pred_3yr <- emmeans(M1_mort_3yr,~1, type='response')
pred_3yr
# Year 4 
M1_mort_4yr <- glmmTMB(mortresp4~1 
+(1|UIC/species_full) + (1|plot_id),
data=s_dat_4,
family = binomial(link = "cloglog"),
na.action=na.fail)
summary(M1_mort_4yr)
pred_4yr <- emmeans(M1_mort_4yr,~1, type='response')
pred_4yr
# Year 5-10
M1_mort_7.5yr <- glmmTMB(mortresp7.5~1 
+(1|UIC/species_full) + (1|plot_id),
data=s_dat_7.5,
family = binomial(link = "cloglog"),
na.action=na.fail)
summary(M1_mort_7.5yr)
pred_7.5yr <- emmeans(M1_mort_7.5yr,~1, type='response')
pred_7.5yr

#M1B_mort_7.5yr <- glmmTMB(mortresp7.5~ log(duration_months) 
#+(1|UIC/species_full) + (1|plot_id),
#data=s_dat_7.5,
#family = binomial(link = "cloglog"),
#na.action=na.fail)
#summary(M1B_mort_7.5yr)
#pred_7.5Byr <- emmeans(M1B_mort_7.5yr,~1, type='response')
#plot(s_dat_7.5$survival_per ~ s_dat_7.5$duration_months)

# Year 10-20
M1_mort_10yr <- glmmTMB(mortresp10~1 
+(1|UIC/species_full) + (1|plot_id),
data=s_dat_10,
family = binomial(link = "cloglog"),
na.action=na.fail)
summary(M1_mort_10yr)
pred_10yr <- emmeans(M1_mort_10yr,~1, type='response')
pred_10yr

### Create table of intercept only model outputs
yr_category <- c("1", "2", "3", "4", "7.5", "10")
model_intercept <- c(NA, NA, NA, NA, NA, NA)
model_lowerCI <- c(NA, NA, NA, NA, NA, NA)
model_upperCI <- c(NA, NA, NA, NA, NA, NA)
model_outputs <- data.frame(yr_category, model_intercept, model_lowerCI, model_upperCI)
model_outputs$model_intercept[1] <- summary(pred_1yr)$prob
model_outputs$model_lowerCI[1] <- summary(pred_1yr)$lower.CL
model_outputs$model_upperCI[1] <- summary(pred_1yr)$upper.CL
model_outputs$model_intercept[2] <- summary(pred_2yr)$prob
model_outputs$model_lowerCI[2] <- summary(pred_2yr)$lower.CL
model_outputs$model_upperCI[2] <- summary(pred_2yr)$upper.CL
model_outputs$model_intercept[3] <- summary(pred_3yr)$prob
model_outputs$model_lowerCI[3] <- summary(pred_3yr)$lower.CL
model_outputs$model_upperCI[3] <- summary(pred_3yr)$upper.CL
model_outputs$model_intercept[4] <- summary(pred_4yr)$prob
model_outputs$model_lowerCI[4] <- summary(pred_4yr)$lower.CL
model_outputs$model_upperCI[4] <- summary(pred_4yr)$upper.CL
model_outputs$model_intercept[5] <- summary(pred_7.5yr)$prob
model_outputs$model_lowerCI[5] <- summary(pred_7.5yr)$lower.CL
model_outputs$model_upperCI[5] <- summary(pred_7.5yr)$upper.CL
model_outputs$model_intercept[6] <- summary(pred_10yr)$prob
model_outputs$model_lowerCI[6] <- summary(pred_10yr)$lower.CL
model_outputs$model_upperCI[6] <- summary(pred_10yr)$upper.CL
model_outputs
## Save intercept model outputs
write.csv(model_outputs, "intercept_models_Intercept_CIs.csv")

######### GLMMTMB MODELS INCLUDING COVARIATES - MODEL SELECTION USING DREDGE - WARNING, SLOW
# Year 1 
M2_mort_1yr <- glmmTMB(mortresp1~ scale(w_meanWD)*network_origin + scale(vals_elev) + scale(vals_pdq) + scale(vals_temp) + scale(planting_sp_no) + scale(w_meanWD)*forest_condition 
+(1|UIC) + (1|species_full) + (1|UIC:species_full) + (1|plot_id),
data=s_dat_1,
family = binomial(link = "cloglog"),
na.action=na.fail)
summary(M2_mort_1yr)
dr_s1 <- dredge(M2_mort_1yr, rank = "AIC")
top_mods_mort1 <- subset(dr_s1,delta <2)
top_mods_mort1
sw(top_mods_mort1)
# Year 2 
M2_mort_2yr <- glmmTMB(mortresp2~scale(w_meanWD)*network_origin + scale(vals_elev) + scale(vals_pdq) + scale(vals_temp) + scale(planting_sp_no) + scale(w_meanWD)*forest_condition 
+(1|UIC) + (1|species_full) + (1|UIC:species_full) + (1|plot_id),
data=s_dat_2,
family = binomial(link = "cloglog"),
na.action=na.fail)
summary(M2_mort_2yr)
dr_s2 <- dredge(M2_mort_2yr, rank = "AIC")
top_mods_mort2 <- subset(dr_s2,delta <2)
top_mods_mort2
sw(top_mods_mort2)
# Year 3
M2_mort_3yr <- glmmTMB(mortresp3~scale(w_meanWD)*network_origin + scale(vals_elev) + scale(vals_pdq) + scale(vals_temp) + scale(planting_sp_no) + scale(w_meanWD)*forest_condition 
+(1|UIC) + (1|species_full) + (1|UIC:species_full) + (1|plot_id),
data=s_dat_3,
family = binomial(link = "cloglog"),
na.action=na.fail)
summary(M2_mort_3yr)
dr_s3 <- dredge(M2_mort_3yr, rank = "AIC")
top_mods_mort3 <- subset(dr_s3,delta <2)
top_mods_mort3
sw(top_mods_mort3)
# Year 4 
M2_mort_4yr <- glmmTMB(mortresp4~scale(w_meanWD)* network_origin + scale(vals_elev) + scale(vals_pdq) + scale(vals_temp) + scale(planting_sp_no) + scale(w_meanWD)*forest_condition 
+(1|UIC) + (1|species_full) + (1|UIC:species_full) + (1|plot_id),
data=s_dat_4,
family = binomial(link = "cloglog"),
na.action=na.fail)
summary(M2_mort_4yr)
dr_s4 <- dredge(M2_mort_4yr, rank = "AIC")
top_mods_mort4 <- subset(dr_s4,delta <2)
top_mods_mort4
sw(top_mods_mort4)
# Year 5-10 # with time
M2_mort_7.5yr <- glmmTMB(mortresp7.5~log(duration_months)+ scale(w_meanWD)*network_origin + scale(vals_elev) + scale(vals_pdq) + scale(vals_temp) + scale(planting_sp_no) + scale(w_meanWD)*forest_condition 
+(1|UIC) + (1|species_full) + (1|UIC:species_full) + (1|plot_id),
data=s_dat_7.5,
family = binomial(link = "cloglog"),
na.action=na.fail)
summary(M2_mort_7.5yr)
dr_s7.5 <- dredge(M2_mort_7.5yr, rank = "AIC")
top_mods_mort7.5 <- subset(dr_s7.5,delta <2)
top_mods_mort7.5
sw(top_mods_mort7.5)
# Year >10 # with time
M2_mort_10yr <- glmmTMB(mortresp10~log(duration_months)+ scale(w_meanWD)*network_origin + scale(vals_elev) + scale(vals_pdq) + scale(vals_temp) + scale(planting_sp_no) + scale(w_meanWD)*forest_condition 
+(1|UIC) + (1|species_full) + (1|UIC:species_full) + (1|plot_id),
data=s_dat_10,
family = binomial(link = "cloglog"),
na.action=na.fail)
summary(M2_mort_10yr)
dr_s15 <- dredge(M2_mort_10yr, rank = "AIC")
dr_s10 <- dr_s15
top_mods_mort10 <- subset(dr_s10,delta <2)
top_mods_mort10
sw(top_mods_mort10)

######## BEST MODELS (need to enter model number from object 'dr_X' manually to select the best performing model)
# Best model Year 1
best_M2_mort_1yr <- get.models(dr_s1, 1)[[1]]
summary(best_M2_mort_1yr)
r2_nakagawa(best_M2_mort_1yr)
icc(best_M2_mort_1yr, by_group = TRUE)
# Best model Year 2
best_M2_mort_2yr <- get.models(dr_s2, 1)[[1]]
summary(best_M2_mort_2yr)
r2_nakagawa(best_M2_mort_2yr)
icc(best_M2_mort_2yr, by_group = TRUE)
# Best model Year 3
best_M2_mort_3yr <- get.models(dr_s3, 1)[[1]]
summary(best_M2_mort_3yr)
r2_nakagawa(best_M2_mort_3yr)
icc(best_M2_mort_3yr, by_group = TRUE)
# Best model Year 4
best_M2_mort_4yr <- get.models(dr_s4, 1)[[1]]
summary(best_M2_mort_4yr)
r2_nakagawa(best_M2_mort_4yr)
icc(best_M2_mort_4yr, by_group = TRUE)
# Best model Year 5-10
best_M2_mort_7.5yr <- get.models(dr_s7.5, 5)[[1]]
summary(best_M2_mort_7.5yr)
r2_nakagawa(best_M2_mort_7.5yr)
icc(best_M2_mort_7.5yr, by_group = TRUE)
# Best model Year >10
best_M2_mort_10yr <- get.models(dr_s10, 1)[[1]]
summary(best_M2_mort_10yr)
r2_nakagawa(best_M2_mort_10yr)
icc(best_M2_mort_10yr, by_group = TRUE)


####### CHECK FOR DENSITY AND HEIGHT EFFECTS
####### Year 1 & 2 data only, separated by 'open' and 'forest' 
# Load data
s_dat <- read.csv("df_survival_Nov2022.csv")
# Subset for Duration - when duration yr_cat = 1, 2, 3, 4, 5, 7.5, 10
s_dat$yr_cat <- as.character(s_dat$yr_cat)
str(s_dat)
s_dat_1 <- subset(s_dat, yr_cat=="1")
s_dat_2 <- subset(s_dat, yr_cat=="2")

# For selecting variables to work with
s_modvars_A <- c("network_origin","study","UIC","plot_id","species_full","genus","species", "family","duration_months", "vals_elev","vals_temp","vals_maxTwm",
"vals_minTcm","vals_precip","vals_pwq","vals_pdq","w_meanWD","planting_density",
"planting_sp_no","survival_per","sample_weight","number_alive","number_dead")
s_modvars_B <- c("network_origin","study","UIC","plot_id","species_full","genus","species", "family","duration_months", "vals_elev","vals_temp","vals_maxTwm",
"vals_minTcm","vals_precip","vals_pwq","vals_pdq","w_meanWD","height_0",
"planting_sp_no","survival_per","sample_weight","number_alive","number_dead")

####### Check for density and height effects in open degraded sites
s_dat_Yr1Open <- subset(s_dat_1, forest_condition=="open_degraded")
plot(s_dat_Yr1Open$survival_per ~ s_dat_Yr1Open$planting_density)
plot(s_dat_Yr1Open$survival_per ~ s_dat_Yr1Open$height_0)

s_dat_Yr2Open <- subset(s_dat_2, forest_condition=="open_degraded")
plot(s_dat_Yr2Open$survival_per ~ s_dat_Yr2Open$planting_density)
plot(s_dat_Yr2Open$survival_per ~ s_dat_Yr2Open$height_0)

s_dat_Yr1Open_dens <- s_dat_Yr1Open [s_modvars_A]
s_dat_Yr2Open_dens <- s_dat_Yr2Open [s_modvars_A]

s_dat_Yr1Open_h0 <- s_dat_Yr1Open [s_modvars_B]
s_dat_Yr2Open_h0 <- s_dat_Yr2Open [s_modvars_B]

mort1A <- cbind(s_dat_Yr1Open_dens$number_dead, s_dat_Yr1Open_dens$number_alive)
mort1B <- cbind(s_dat_Yr1Open_h0$number_dead, s_dat_Yr1Open_h0$number_alive)
mort2A <- cbind(s_dat_Yr2Open_dens$number_dead, s_dat_Yr2Open_dens$number_alive)
mort2B <- cbind(s_dat_Yr2Open_h0$number_dead, s_dat_Yr2Open_h0$number_alive)

### DENSITY
M1_year1open_dens <- glmmTMB(mort1A~planting_density
+(1|UIC/species_full) + (1|plot_id),
data=s_dat_Yr1Open_dens,
family = binomial(link = "cloglog"),
na.action=na.omit)
summary(M1_year1open_dens)

M1_year2open_dens <- glmmTMB(mort2A~planting_density
+(1|UIC/species_full) + (1|plot_id),
data=s_dat_Yr2Open_dens,
family = binomial(link = "cloglog"),
na.action=na.omit)
summary(M1_year2open_dens)

### HEIGHT
M1_year1open_h0 <- glmmTMB(mort1B~height_0
+(1|UIC/species_full) + (1|plot_id),
data=s_dat_Yr1Open_h0,
family = binomial(link = "cloglog"),
na.action=na.omit)
summary(M1_year1open_h0)
ggpredict(M1_year1open_h0)

M1_year2open_h0 <- glmmTMB(mort2B~height_0
+(1|UIC/species_full) + (1|plot_id),
data=s_dat_Yr2Open_h0,
family = binomial(link = "cloglog"),
na.action=na.omit)
summary(M1_year2open_h0)
ggpredict(M1_year2open_h0)

####### Check for density and height effects in forest enrichment sites
s_dat_Yr1Closed <- subset(s_dat_1, forest_condition=="forest_enrichment")
plot(s_dat_Yr1Closed$survival_per ~ s_dat_Yr1Closed$planting_density)
plot(s_dat_Yr1Closed$survival_per ~ s_dat_Yr1Closed$height_0)
s_dat_Yr2Closed <- subset(s_dat_2, forest_condition=="forest_enrichment")
plot(s_dat_Yr2Closed$survival_per ~ s_dat_Yr2Closed$planting_density)
plot(s_dat_Yr2Closed$survival_per ~ s_dat_Yr2Closed$height_0)

s_dat_Yr1Closed_dens <- s_dat_Yr1Closed [s_modvars_A]
s_dat_Yr2Closed_dens <- s_dat_Yr2Closed [s_modvars_A]

s_dat_Yr1Closed_h0 <- s_dat_Yr1Closed [s_modvars_B]
s_dat_Yr2Closed_h0 <- s_dat_Yr2Closed [s_modvars_B]

mort1C <- cbind(s_dat_Yr1Closed_dens$number_dead, s_dat_Yr1Closed_dens$number_alive)
mort1D <- cbind(s_dat_Yr1Closed_h0$number_dead, s_dat_Yr1Closed_h0$number_alive)
mort2C <- cbind(s_dat_Yr2Closed_dens$number_dead, s_dat_Yr2Closed_dens$number_alive)
mort2D <- cbind(s_dat_Yr2Closed_h0$number_dead, s_dat_Yr2Closed_h0$number_alive)

### DENSITY
M1_year1closed_dens <- glmmTMB(mort1C~planting_density
+(1|UIC) + (1|plot_id),
data=s_dat_Yr1Closed_dens,
family = binomial(link = "cloglog"),
na.action=na.omit)
summary(M1_year1closed_dens)

M1_year2closed_dens <- glmmTMB(mort2C~planting_density
+(1|UIC/species_full) + (1|plot_id),
data=s_dat_Yr2Closed_dens,
family = binomial(link = "cloglog"),
na.action=na.omit)
summary(M1_year2closed_dens)

### HEIGHT
M1_year1closed_h0 <- glmmTMB(mort1D~height_0
+(1|UIC/species_full) + (1|plot_id),
data=s_dat_Yr1Closed_h0,
family = binomial(link = "cloglog"),
na.action=na.omit)
summary(M1_year1closed_h0)
ggpredict(M1_year1closed_h0)

M1_year2closed_h0 <- glmmTMB(mort2D~height_0
+(1|UIC/species_full) + (1|plot_id),
data=s_dat_Yr2Closed_h0,
family = binomial(link = "cloglog"),
na.action=na.omit)
summary(M1_year2closed_h0)
ggpredict(M1_year2closed_h0)


